// Contains class definitions
// Copyright (C) 1997 by John P. Weiss
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Artistic License, included as the file
// "LICENSE" in the source code archive.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//
// You should have received a copy of the file "LICENSE", containing
// the License John Weiss originally placed this program under.
#include "pAudio.h"




//|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
//
// Button Data Definitions
//
//|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
// The Stop button - a Square
//
RawPixData stopd={
  FALSE,
  2.0,
  1.0,
  32,
  1,
  TRUE,
  {".75,.25  1.24,.25  1.24,.74  .75,.74  .75,.25",
   "","","","","","","","",""},
  "5",
  "p" };

// The Play-Pause button - a long triangle and two bars.
//
RawPixData playpaused={
  FALSE,
  2.0,
  1.0,
  32,
  3,
  TRUE,
  {".5,.25  .99,.49  .99,.5  .5,.74  .5,.25",
   "1.25,.25  1.374,.25  1.374,.74  1.25,.74  1.25,.25",
   "1.5,.25  1.624,.25  1.624,.74  1.5,.74  1.5,.25",
   "","","","","","",""},
  "5 5 5",
  "ppp" };


// The Fast-Forward button - two triangles with an extra line on the
// back end.
//
RawPixData ffd={
  FALSE,
  2.0,
  1.0,
  32,
  2,
  TRUE,
  {".75,.25  .99,.49  .99,.5  .75,.74  .75,.25",
   "1.0,.25  1.24,.49  1.24,.5  1.0,.74  1.0,.25",
   "","","","","","","",""},
  "5 5",
  "pp" };


// The Next button - ff plus a 2-pixel wide rectangle just after the
// second triangle.
//
RawPixData nextd={
  FALSE,
  2.0,
  1.0,
  32,
  3,
  TRUE,
  {"1.25,.25  1.29,.25  1.29,.74  1.25,.74  1.25,.25",
   ".75,.25  .99,.49  .99,.5  .75,.74  .75,.25",
   "1.0,.25  1.24,.49  1.24,.5  1.0,.74  1.0,.25",
   "","","","","","",""},
  "5 5 5",
  "ppp" };


// The Rewind button - mirror of the ffd button
//
RawPixData rewd={
  FALSE,
  2.0,
  1.0,
  32,
  2,
  TRUE,
  {"1.24,.25  1.0,.49  1.0,.5  1.24,.74  1.24,.25",
   ".99,.25  .75,.49  .75,.5  .99,.74  .99,.25",
   "","","","","","","",""},
  "5 5",
  "pp" };


// The Prev button - mirror of the nextd button
//
RawPixData prevd={
  FALSE,
  2.0,
  1.0,
  32,
  3,
  TRUE,
  {".74,.25  .74,.74  .7,.74  .7,.25  .74,.25",
   "1.24,.25  1.0,.49  1.0,.5  1.24,.74  1.24,.25",
   ".99,.25  .75,.49  .75,.5  .99,.74  .99,.25",
   "","","","","","",""},
  "5 5 5",
  "ppp" };




// ***************
//  Here, we define the actual functions


//||||||||||||||||||||||||||||||||||||||||||||||||
//
//  Class pAudio
//
//||||||||||||||||||||||||||||||||||||||||||||||||




// Constructor for the function control-panel
//
pAudio::pAudio( QWidget *parent, float bscale ) 
  : QWidget( parent )
{
  // Create the buttons
  fbw_p = QPoint( 0, 0 );

  createChildren( bscale );
  locateChildren();
  resize( fbw_s );
  moveChildren();
  moveAll( fbw_p );
}



// Destructor for the function control-panel
//
pAudio::~pAudio( void )
{
   delete stopb;
   delete playpauseb;
   delete prevb;
   delete nextb;
   delete rewb;
   delete ffb;
}



// Creates the child widgets and connects some signals and slots.
//
void pAudio::createChildren( float bscale )
{
  stopb = new PixButton( this, stopd, bscale );
  playpauseb = new PixButton( this, playpaused, bscale );
  prevb = new PixButton( this, prevd, bscale );
  nextb = new PixButton( this, nextd, bscale );
  rewb = new PixButton( this, rewd, bscale );
  ffb = new PixButton( this, ffd, bscale );
}


// Initializes the positions of the buttons
//
void pAudio::locateChildren( void )
{
  stop_p = QPoint( bsep, bsep );
  prev_p = stop_p + QPoint( 0, stopb->height() + bsep );
  rew_p = prev_p + QPoint( 0, prevb->height() + bsep );
  plps_p = stop_p + QPoint( stopb->width() + bsep, 0 );
  next_p = plps_p + QPoint( 0, playpauseb->height() + bsep );
  ff_p = next_p + QPoint( 0, nextb->height() + bsep );

  fbw_s = QSize( (ff_p.x() + ffb->width() + bsep),
			  (ff_p.y() + ffb->height() + bsep)
			  );
}


// Moves all of the children en-masse.
//
void pAudio::moveChildren( void )
{
  stopb->move( fbw_p + stop_p );
  prevb->move( fbw_p + prev_p );
  rewb->move( fbw_p + rew_p );
  playpauseb->move( fbw_p + plps_p );
  nextb->move( fbw_p + next_p );
  ffb->move( fbw_p + ff_p );
}


// Changes the widget palette
//
void pAudio::changePalette(QPalette& p)
{
  setPalette(p);
  stopb->setPalette(p);
  playpauseb->setPalette(p);
  prevb->setPalette(p);
  nextb->setPalette(p);
  rewb->setPalette(p);
  ffb->setPalette(p);

  stopb->bRepaint();
  playpauseb->bRepaint();
  prevb->bRepaint();
  nextb->bRepaint();
  rewb->bRepaint();
  ffb->bRepaint();
}





//||||||||||||||||||||||||||||||||
//
// End.
//
